summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/plugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/plugin.h')
-rw-r--r--kpilot/lib/plugin.h62
1 files changed, 31 insertions, 31 deletions
diff --git a/kpilot/lib/plugin.h b/kpilot/lib/plugin.h
index b825b899..d768b601 100644
--- a/kpilot/lib/plugin.h
+++ b/kpilot/lib/plugin.h
@@ -29,7 +29,7 @@
** Bug reports and questions can be sent to kde-pim@kde.org
*/
-#include <qstringlist.h>
+#include <tqstringlist.h>
#include "syncAction.h"
@@ -67,11 +67,11 @@ namespace Pilot
* and it's what is used in the KPilot conduit configuration dialog.
* The factory is asked for a "ConduitConfigBase" object.
*
* NB. The reason that this is a QObject which needs to create a
* separate widget - instead of a QWidget subclass - has to do with
* layouting. If you make the widget with designer then the easiest
* thing to do is to use a grid layout there. Making ConduitConfigBase
* a QWidget subclass would require an additional layout here, which
* seems a little foolish.
*
*/
@@ -83,7 +83,7 @@ public:
* Constructor. Creates a conduit configuration support object
* with the given parent @p parent and name (optional) @p n.
*/
- ConduitConfigBase(QWidget *parent=0L, const char *n=0L);
+ ConduitConfigBase(TQWidget *parent=0L, const char *n=0L);
/** Destructor. */
virtual ~ConduitConfigBase();
@@ -100,7 +100,7 @@ public:
} ;
/** Accessor for the actual widget for the configuration. */
- QWidget *widget() const
+ TQWidget *widget() const
{
return fWidget;
} ;
@@ -124,7 +124,7 @@ public:
*/
virtual bool maybeSave();
- QString conduitName() const { return fConduitName; } ;
+ TQString conduitName() const { return fConduitName; } ;
/**
* This is the function that does the work of adding an about
@@ -139,7 +139,7 @@ public:
* @param data The KAboutData that is used.
*
*/
- static void addAboutPage(QTabWidget *w,
+ static void addAboutPage(TQTabWidget *w,
KAboutData *data=0L);
/**
@@ -154,20 +154,20 @@ public:
* @param parent The widget that holds the about widget.
* @param data The KAboutData that is used to populate the widget.
*/
- static QWidget *aboutPage(QWidget *parent, KAboutData *data=0L);
+ static TQWidget *aboutPage(TQWidget *parent, KAboutData *data=0L);
protected:
/**
* This function provides the string for the prompt used
* in maybeSave(). Override it to change the text.
*/
- virtual QString maybeSaveText() const;
+ virtual TQString maybeSaveText() const;
void unmodified() { fModified=false; } ;
bool fModified;
- QWidget *fWidget;
- QString fConduitName;
+ TQWidget *fWidget;
+ TQString fConduitName;
protected slots:
@@ -196,7 +196,7 @@ class KDE_EXPORT CUDCounter
public:
/** Create new counter initialized to 0, and be told what
* kind of CUD we're counting (PC or Handheld, etc.) */
- CUDCounter(QString s);
+ CUDCounter(TQString s);
/** Track the creation of @p c items */
void created(unsigned int c=1);
@@ -227,12 +227,12 @@ public:
* objects created, updated, deleted. This
* string is already i18n()ed.
*/
- QString moo() const;
+ TQString moo() const;
/** Type of counter(Handheld or PC). This string is already
* i18n()ed.
*/
- QString type() const { return fType; }
+ TQString type() const { return fType; }
private:
/** keep track of Creates, Updates, Deletes, and Total
* number of records so we can detect abnormal behavior and
@@ -243,7 +243,7 @@ private:
/** What kind of CUD are we keeping track of so we can
* moo() it out later? (PC, Handheld, etc.)
*/
- QString fType;
+ TQString fType;
} ;
@@ -264,7 +264,7 @@ Q_OBJECT
public:
ConduitAction(KPilotLink *,
const char *name=0L,
- const QStringList &args = QStringList());
+ const TQStringList &args = TQStringList());
virtual ~ConduitAction();
/** ConduitAction is done doing work. Allow it to sanity-check the
@@ -272,7 +272,7 @@ public:
*/
void finished();
- QString conduitName() const { return fConduitName; } ;
+ TQString conduitName() const { return fConduitName; } ;
/** Retrieve the sync mode set for this action. */
const SyncMode &syncMode() const { return fSyncDirection; };
@@ -338,13 +338,13 @@ protected:
* @param retrieved indicator whether the database had to be loaded
* from the handheld.
*/
- bool openDatabases(const QString &dbName, bool*retrieved=0L);
+ bool openDatabases(const TQString &dbName, bool*retrieved=0L);
/**
* Name of the conduit; might be changed by subclasses. Should
* normally be set in the constructor.
*/
- QString fConduitName;
+ TQString fConduitName;
/** Every plugin has 2 CUDCounters--one for keeping track of
* changes made to PC data and one for keeping track of Palm data. */
@@ -370,7 +370,7 @@ Q_OBJECT
public:
ConduitProxy(KPilotLink *,
- const QString &desktopName,
+ const TQString &desktopName,
const SyncAction::SyncMode &m);
protected:
@@ -379,17 +379,17 @@ protected slots:
void execDone(SyncAction *);
protected:
- QString fDesktopName;
- QString fLibraryName;
+ TQString fDesktopName;
+ TQString fLibraryName;
ConduitAction *fConduit;
} ;
/** A namespace containing only static helper methods. */
namespace PluginUtility
{
/** Searches the argument list for --foo=bar and returns bar, QString::null if not found.
* Don't include the -- in the argname. */
- QString findArgument(const QStringList &a, const QString argname);
+ TQString findArgument(const TQStringList &a, const TQString argname);
/**
* This function attempts to detect whether or not the given
@@ -399,14 +399,14 @@ namespace PluginUtility
* The current approach is to ask the DCOP server if the application
* has registered.
*/
- bool isRunning(const QCString &appName);
+ bool isRunning(const TQCString &appName);
/**
* Check a given library for its version, returning 0 if no
* version symbol is found.
*/
unsigned long pluginVersion(const KLibrary *);
- QString pluginVersionString(const KLibrary *);
+ TQString pluginVersionString(const KLibrary *);
}
/**
@@ -420,7 +420,7 @@ namespace PluginUtility
* Q_OBJECT
*
* public:
-* KPilotPlugin(QObject * = 0L,const char * = 0L) ;
+* KPilotPlugin(TQObject * = 0L,const char * = 0L) ;
* virtual ~KPilotPlugin();
* </pre>
*
@@ -440,10 +440,10 @@ namespace PluginUtility
*
* <pre>
* protected:
-* virtual QObject* createObject( QObject* parent = 0,
+* virtual TQObject* createObject( TQObject* parent = 0,
* const char* name = 0,
-* const char* classname = "QObject",
-* const QStringList &args = QStringList() );
+* const char* classname = "TQObject",
+* const TQStringList &args = TQStringList() );
* </pre>
*
* More boilerplate, and support for an instance and about data, used
@@ -67,11 +67,11 @@ namespace Pilot
* The factory is asked for a "ConduitConfigBase" object.
*
-* NB. The reason that this is a QObject which needs to create a
-* separate widget - instead of a QWidget subclass - has to do with
+* NB. The reason that this is a TQObject which needs to create a
+* separate widget - instead of a TQWidget subclass - has to do with
* layouting. If you make the widget with designer then the easiest
* thing to do is to use a grid layout there. Making ConduitConfigBase
@@ -67,11 +67,11 @@ namespace Pilot
* layouting. If you make the widget with designer then the easiest
* thing to do is to use a grid layout there. Making ConduitConfigBase
-* a QWidget subclass would require an additional layout here, which
+* a TQWidget subclass would require an additional layout here, which
* seems a little foolish.
*
@@ -379,17 +379,17 @@ protected slots:
namespace PluginUtility
{
- /** Searches the argument list for --foo=bar and returns bar, QString::null if not found.
+ /** Searches the argument list for --foo=bar and returns bar, TQString::null if not found.
* Don't include the -- in the argname. */